@@ -8,19 +8,19 @@ from FreeTAKServer.controllers.serializers import xml_serializer
 loggingConstants = LoggingConstants()
 logger = CreateLoggerController("SendCoTAbstract").getLogger()
 
+
 class SendCoTAbstractController(ABC):
     Event = event
-    def __init__(self, object):
-        pass
 
-    def fill_object(self, object, tempObject, RawCoT, addToDB = MainConfig.SaveCoTToDB):
+    def fill_object(self, object, tempObject, RawCoT, addToDB=MainConfig.SaveCoTToDB):
         try:
             object.modelObject = self.create_model_object(tempObject, RawCoT.xmlString)
 
         except Exception as e:
             if tempObject.type != "other":
                 self.handel_serialization_exception(object, RawCoT)
-                logger.error('an undocumented CoT has been sent returning the error ' + str(e) + ' please post this as an issue on the FTS git so we can document and fix it')
+                logger.error('an undocumented CoT has been sent returning the error ' + str(
+                    e) + ' please post this as an issue on the FTS git so we can document and fix it')
                 return 1
             else:
                 logger.warning('there has been an exception in the creation of the model object ' + str(e))
@@ -37,7 +37,8 @@ class SendCoTAbstractController(ABC):
                 pass
         except Exception as e:
             print(e)
-            logger.warning('there has been an exception in the creation of a database instance of this object ' + str(e))
+            logger.warning(
+                'there has been an exception in the creation of a database instance of this object ' + str(e))
             raise Exception(e)
         self.setObject(object)
 
@@ -50,6 +51,7 @@ class SendCoTAbstractController(ABC):
 
         modelInstance = xml_serializer.XmlSerializer().from_format_to_fts_object(xmlString, tempObject)
         return modelInstance
+
     def create_xml_string(self, modelObject):
         """
         this function calls the model to xml serializer within XMLCoTController
@@ -60,7 +62,7 @@ class SendCoTAbstractController(ABC):
             xml = XMLCoTController().serialize_model_to_CoT(modelObject, 'event')
             return xml
         except Exception as e:
-            logger.error('there has been an exception in the creation of the xml string ' +str(e))
+            logger.error('there has been an exception in the creation of the xml string ' + str(e))
             return -1
 
     def handel_serialization_exception(self, object, RawCoT):
@@ -73,7 +75,6 @@ class SendCoTAbstractController(ABC):
         object.clientInformation = RawCoT.clientInformation
         self.setObject(object)
 
-
     def setObject(self, object):
         self.Object = object
 
@@ -81,4 +82,4 @@ class SendCoTAbstractController(ABC):
         return self.Object
 
     def reloadXmlString(self):
-        self.Object.xmlString = self.create_xml_string(self.Object.modelObject)
\ No newline at end of file
+        self.Object.xmlString = self.create_xml_string(self.Object.modelObject)
