@@ -6,8 +6,8 @@ from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingCons
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
 from FreeTAKServer.controllers.SSLSocketController import SSLSocketController
 
-loggingConstants = LoggingConstants()
-logger = CreateLoggerController("SSLDataPackageServer").getLogger()
+loggingConstants = LoggingConstants(log_name="FTS-SSL_DataPackage_Service")
+logger = CreateLoggerController("FTS-SSL_DataPackage_Service", logging_constants=loggingConstants).getLogger()
 
 class SSLDataPackageService(FlaskFunctions):
     def startup(self, ip, port, pipe):
@@ -39,7 +39,7 @@ class SSLDataPackageService(FlaskFunctions):
             self.setSSL(True)
             wsgi.server(sock=wrap_ssl(listen((DataPackageServerConstants().IP, int(HTTPPORT))), keyfile=MainConfig.unencryptedKey,
                                       certfile=MainConfig.pemDir,
-                                      server_side=True, ca_certs=MainConfig.CA), site=app)
+                                      server_side=True, ca_certs=MainConfig.CA, cert_reqs=ssl.CERT_REQUIRED), site=app)
         except Exception as e:
             logger.error('there has been an exception in Data Package service startup ' + str(e))
             return -1
