@@ -1,6 +1,7 @@
+from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.StartTimeVariables import StartTimeVariables as vars
 
-class StartTime:
+class StartTime(FTSProtocolObject):
     @staticmethod
     def Checklist(INTAG = vars.Checklist().INTAG):
         starttime = StartTime()
